@@ -28,8 +28,8 @@ class TestDanglingKeys(ChecksTestCase):
         cnt_min = 20
         cnt_max = 40
         keys = [self.get_random_string('key') for _ in range(random.randint(cnt_min, cnt_max))]
-        ref_file = self.build_prepfile(keys)
-        trans_file = self.build_prepfile(keys)
+        ref_file = self.build_propfile(keys)
+        trans_file = self.build_propfile(keys)
         self.check(trans_file, ref_file)
 
     def test_translation_with_faults(self) -> None:
@@ -43,8 +43,8 @@ class TestDanglingKeys(ChecksTestCase):
         how_many_less = random.randint(1, upper_bound)
         ref_keys = trans_keys[:(how_many_less * -1)]
 
-        ref_file = self.build_prepfile(ref_keys)
-        trans_file = self.build_prepfile(trans_keys)
+        ref_file = self.build_propfile(ref_keys)
+        trans_file = self.build_propfile(trans_keys)
         self.check(trans_file, ref_file, exp_errors = how_many_less)
 
     # #################################################################################################
