@@ -9,6 +9,7 @@
 import copy
 import random
 from pathlib import Path
+from typing import List
 from unittest.mock import Mock, mock_open, patch
 
 from transtool.config.builder import ConfigBuilder
@@ -22,7 +23,7 @@ class TestPropFile(TestCase):
 
     def _generate_propfile_with_content(self, config: Config) -> PropFile:
         """
-        Creates instance of PropFile and fills it with randonly generated content.
+        Creates instance of PropFile and fills it with randomly generated content.
         :param config: Config to be used while constructing instance.
         """
         propfile = PropFile(config)
@@ -314,7 +315,7 @@ class TestPropFile(TestCase):
                     expected.append(item.to_string())
 
                 fh = manager()
-                # FIXME: LF/CRLF should configurable
+                # FIXME: LF/CRLF should be configurable
                 fh.write.assert_called_once_with('\n'.join(expected))
 
     def test_save(self) -> None:
@@ -342,13 +343,52 @@ class TestPropFile(TestCase):
         """
         Checks if save() will fail if no target file name is given nor object's
         `file` property is `None`.
-        :return:
         """
         config = Config()
         propfile = PropFile(config)
         with self.assertRaises(ValueError):
             propfile.save()
 
+    def test_save_no_trailing_lf(self) -> None:
+        """
+        Ensures that save() will not add any trailing LF as last line
+        if source data do not end up with empty line.
+        """
+        config = Config()
+        propfile = PropFile(config)
+
+        item = Translation(self.get_random_string('key'), self.get_random_string('value'))
+        propfile.append(item)
+
+        # Check file content is written as expected.
+        expected = [item.to_string()]
+
+        self.do_compare_output_with_saved_content(propfile, expected)
+
+    def test_save_trailing_lf_is_saved(self) -> None:
+        """
+        Ensures that save() will do add any trailing LF as last line
+        if source data ends with empty line.
+        """
+        config = Config()
+        propfile = PropFile(config)
+
+        item = Translation(self.get_random_string('key'), self.get_random_string('value'))
+        propfile.append(item)
+        propfile.append(Blank())
+
+        # Check file content is written as expected.
+        expected = [item.to_string(), '']
+
+        self.do_compare_output_with_saved_content(propfile, expected)
+
+    def do_compare_output_with_saved_content(self, propfile: PropFile, expected: List[str]) -> None:
+        with patch('builtins.open', mock_open()) as manager:
+            propfile.save(self.get_random_string())
+            fh = manager()
+            # FIXME: LF/CRLF should be configurable
+            fh.write.assert_called_once_with('\n'.join(expected))
+
     # #################################################################################################
 
     @patch('pathlib.Path.exists')
@@ -391,8 +431,15 @@ class TestPropFile(TestCase):
 
     # #################################################################################################
 
-    def test_update(self) -> None:
+    def test_update_just_keys(self) -> None:
+        self.do_test_update(write_content = False)
+
+    def test_update_with_write_content(self) -> None:
+        self.do_test_update(write_content = True)
+
+    def do_test_update(self, write_content: bool) -> None:
         config = Config()
+        config.write_content = write_content
         ConfigBuilder._setup_checkers(config)  # noqa: WPS437
 
         # Generate reference file and its contents
@@ -455,7 +502,10 @@ class TestPropFile(TestCase):
                     self.assertEqual(translation_clone.items[ref_idx].value, trans_item.value)
                     continue
                 if isinstance(trans_item, Comment):
-                    expected = Comment.comment_out_key(config, ref_item.key, ref_item.value)
+                    if write_content:
+                        expected = Comment.comment_out_key(config, ref_item.key, ref_item.value)
+                    else:
+                        expected = Comment.comment_out_key(config, ref_item.key)
                     self.assertEqual(expected, trans_item.to_string())
                     continue
 
