@@ -133,7 +133,10 @@ class PropFile(object):
                         # But as we wrote reference comment already, let's put just a key, without the value.
                         tmp.append(Comment.get_commented_out_key_comment(self.config, item.key))
                     else:
-                        tmp.append(Comment.get_commented_out_key_comment(self.config, item.key, item.value))
+                        if self.config.write_content:
+                            tmp.append(Comment.get_commented_out_key_comment(self.config, item.key, item.value))
+                        else:
+                            tmp.append(Comment.get_commented_out_key_comment(self.config, item.key))
             else:
                 raise TypeError(f'Unknown entry type: {type(item)} at position {idx + 1}')
 
@@ -223,7 +226,7 @@ class PropFile(object):
 
     def save(self, target_file_name: Union[Path, None] = None) -> None:
         """
-        Saves content of the propfile.
+        Saves content of the properties file.
         """
 
         if not target_file_name:
@@ -235,6 +238,12 @@ class PropFile(object):
         for item in self.items:
             content.append(item.to_string())
 
+        # If last line is empty line, we need to add LF manually as join() won't do that.
+        if self.items:
+            last_item_idx = len(self.items) - 1
+            if isinstance(self.items[last_item_idx], Blank) == '':
+                content.append('')
+
         Log.i(f'Writing: {target_file_name}')
         with open(target_file_name, 'w') as fh:
             # FIXME: LF/CRLF should configurable
